@@ -4,4 +4,6 @@
 #' @importFrom BBmisc %nin%
 #' @importFrom BBmisc is.error
 #' @importFrom BBmisc setClasses
-NULL
+#' @importFrom BBmisc isDirectory
+
+UNITCONVERT = setNames(c(1L, 1024L, 1048576L, 1073741824L), c("b", "kB", "Mb", "Gb"))
\ No newline at end of file
